@@ -5,7 +5,7 @@ Weasel::Driver::Selenium2 - Weasel driver wrapping Selenium::Remote::Driver
 
 =head1 VERSION
 
-0.10
+0.11
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,7 @@ use English qw(-no_match_vars);
 use Moose;
 with 'Weasel::DriverRole';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 =head1 ATTRIBUTES
@@ -463,7 +463,11 @@ sub _resolve_id {
 sub _scroll {
     my ($self, $id) = @_;
 
-    $self->_driver->execute_script('arguments[0].scrollIntoView(true);',
+    $self->_driver->execute_script('arguments[0].scrollIntoView('
+                                 . '{block: "center", '
+                                 .  'inline: "center", '
+                                 .  'behavior: "smooth"'
+                                 . '});',
                                    $id);
     return $id;
 }
@@ -505,11 +509,10 @@ L<perl-weasel@googlegroups.com|mailto:perl-weasel@googlegroups.com>.
 
 =head1 LICENSE AND COPYRIGHT
 
- (C) 2016-2019  Erik Huelsmann
+ (C) 2016-2020  Erik Huelsmann
 
 Licensed under the same terms as Perl.
 
 =cut
 
 1;
-
